@@ -2,13 +2,9 @@ from django.conf.urls.defaults import patterns, url
 from django.contrib.admin.views.decorators import staff_member_required
 
 from oscar.core.application import Application
-from oscar.apps.dashboard.nav import register, Node
 
 from datacash.views import TransactionListView, TransactionDetailView
 
-node = Node('Datacash', 'datacash-transaction-list')
-register(node, 100)
-
 
 class DatacashDashboardApplication(Application):
     name = None
@@ -17,9 +13,9 @@ class DatacashDashboardApplication(Application):
 
     def get_urls(self):
         urlpatterns = patterns('',
-            url(r'^transactions/$', self.list_view.as_view(), 
+            url(r'^transactions/$', self.list_view.as_view(),
                 name='datacash-transaction-list'),
-            url(r'^transactions/(?P<pk>\d+)/$', self.detail_view.as_view(), 
+            url(r'^transactions/(?P<pk>\d+)/$', self.detail_view.as_view(),
                 name='datacash-transaction-detail'),
         )
         return self.post_process_urls(urlpatterns)
