@@ -6,11 +6,10 @@ from datacash.models import OrderTransaction
 class TransactionListView(ListView):
     model = OrderTransaction
     context_object_name = 'transactions'
-    template_name = 'dashboard/datacash/transaction_list.html'
-    paginate_by = 20
+    template_name = 'datacash/dashboard/transaction_list.html'
 
 
 class TransactionDetailView(DetailView):
     model = OrderTransaction
     context_object_name = 'txn'
-    template_name = 'dashboard/datacash/transaction_detail.html'
+    template_name = 'datacash/dashboard/transaction_detail.html'
